package com.ruoyi.ems.controller;

import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.ems.domain.EmsFacsType;
import com.ruoyi.ems.service.IEmsFacsTypeService;
import io.swagger.annotations.Api;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 能源设施/系统分类Controller
 * 
 * @author ruoyi
 * @date 2024-07-11
 */
@RestController
@RequestMapping("/basecfg/facstype")
@Api(value = "FacsTypeController", description = "设施分类管理")
public class FacsTypeController extends BaseController
{
    @Autowired
    private IEmsFacsTypeService emsFacsTypeService;

    /**
     * 查询能源设施/系统分类列表
     */
    @RequiresPermissions("basecfg:facstype:list")
    @GetMapping("/list")
    public TableDataInfo list(EmsFacsType emsFacsType)
    {
        startPage();
        List<EmsFacsType> list = emsFacsTypeService.selectFacsTypeList(emsFacsType);
        return getDataTable(list);
    }

    /**
     * 获取所有能源设施/系统分类
     * @return 能源设施/系统分类列表
     */
    @GetMapping("/listall")
    public AjaxResult listAll() {
        List<EmsFacsType> list = emsFacsTypeService.selectFacsTypeList(new EmsFacsType());
        return success(list);
    }

    /**
     * 导出能源设施/系统分类列表
     */
    @RequiresPermissions("basecfg:facstype:export")
    @Log(title = "能源设施/系统分类", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EmsFacsType emsFacsType)
    {
        List<EmsFacsType> list = emsFacsTypeService.selectFacsTypeList(emsFacsType);
        ExcelUtil<EmsFacsType> util = new ExcelUtil<EmsFacsType>(EmsFacsType.class);
        util.exportExcel(response, list, "能源设施/系统分类数据");
    }

    /**
     * 获取能源设施/系统分类详细信息
     */
    @RequiresPermissions("basecfg:facstype:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(emsFacsTypeService.selectFacsTypeById(id));
    }

    /**
     * 新增能源设施/系统分类
     */
    @RequiresPermissions("basecfg:facstype:add")
    @Log(title = "能源设施/系统分类", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EmsFacsType emsFacsType)
    {
        return toAjax(emsFacsTypeService.insertFacsType(emsFacsType));
    }

    /**
     * 修改能源设施/系统分类
     */
    @RequiresPermissions("basecfg:facstype:edit")
    @Log(title = "能源设施/系统分类", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EmsFacsType emsFacsType)
    {
        return toAjax(emsFacsTypeService.updateFacsType(emsFacsType));
    }

    /**
     * 删除能源设施/系统分类
     */
    @RequiresPermissions("basecfg:facstype:remove")
    @Log(title = "能源设施/系统分类", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(emsFacsTypeService.deleteFacsTypeByIds(ids));
    }
}
